@@ -149,6 +149,8 @@ class Node(BaseModel):
         add_model: T.Type[BaseModel]
         patch_model: T.Type[BaseModel]
 
+        url: str = None
+
     # TODO make equality and hashing
 
     @property
@@ -348,7 +350,7 @@ class Node(BaseModel):
         rel_d = cls.make_gql_d_from_rel_d_input(rel_d_input=relationships_input or {})
         input_d.update(rel_d)
         variables = {"input": jsonable_encoder(input_d), "upsert": upsert}
-        j = await gql(query_str=query_str, variables=variables)
+        j = await gql(query_str=query_str, variables=variables, url=cls.Dgraph.url)
         node_d = j["data"][f"add{cls.Dgraph.typename}"][cls.Dgraph.payload_node_name][0]
         return resolver.parse_obj_nested(node_d)
 
@@ -410,7 +412,7 @@ class Node(BaseModel):
 
         resolver = given_resolver or self._used_resolver
         query_str = resolver.make_update_mutation_str()
-        j = await gql(query_str=query_str, variables=variables)
+        j = await gql(query_str=query_str, variables=variables, url=self.Dgraph.url)
         node_d_lst = j["data"][f"update{self.Dgraph.typename}"][
             self.Dgraph.payload_node_name
         ]
@@ -430,7 +432,7 @@ class Node(BaseModel):
         resolver = given_resolver or self._used_resolver
         query_str = resolver.make_delete_mutation_str()
         variables = {"filter": {"id": self.id}}
-        j = await gql(query_str=query_str, variables=variables)
+        j = await gql(query_str=query_str, variables=variables, url=self.Dgraph.url)
         node_d_lst = j["data"][f"delete{self.Dgraph.typename}"][
             self.Dgraph.payload_node_name
         ]
