@@ -99,9 +99,8 @@ class Resolver(BaseModel, T.Generic[NodeType]):
 
     async def query(self) -> T.List[NodeType]:
         s = self.make_query_query_str()
-        lst: T.List[dict] = (await execute.gql(query_str=s))["data"][
-            self.query_query_name()
-        ]
+        res = await execute.gql(query_str=s, url=self.node.Dgraph.url)
+        lst: T.List[dict] = res["data"][self.query_query_name()]
         return [self.parse_obj_nested(d) for d in lst]
 
     def parse_obj_nested(self, gql_d: dict) -> NodeType:
@@ -127,7 +126,8 @@ class Resolver(BaseModel, T.Generic[NodeType]):
 
     async def _get(self, kwargs_d: dict) -> T.Optional[NodeType]:
         s = self.make_get_query_str(kwargs_d=kwargs_d)
-        obj = (await execute.gql(query_str=s))["data"][self.get_query_name()]
+        res = await execute.gql(query_str=s, url=self.node.Dgraph.url)
+        obj = res["data"][self.get_query_name()]
         if obj:
             return self.parse_obj_nested(obj)
         return None
